# Schema Docs

- [1. ![badge](https://img.shields.io/badge/Optional-yellow) Property `root > address`](#address)
  - [1.1. root > address > items](#autogenerated_heading_2)
- [2. ![badge](https://img.shields.io/badge/Optional-yellow) Property `root > addressLines`](#addressLines)
  - [2.1. root > addressLines > items](#autogenerated_heading_3)
- [3. ![badge](https://img.shields.io/badge/Optional-yellow) Property `root > arrayEmpty`](#arrayEmpty)
  - [3.1. root > arrayEmpty > items](#autogenerated_heading_4)

| Type                      | `object`                                                                                                            |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
|                           |                                                                                                                     |

**Description:** A little food fun

| Property                         | Pattern | Type  | Deprecated | Definition | Title/Description     |
| -------------------------------- | ------- | ----- | ---------- | ---------- | --------------------- |
| - [address](#address )           | No      | array | No         | -          | -                     |
| - [addressLines](#addressLines ) | No      | array | No         | -          | list of address lines |
| - [arrayEmpty](#arrayEmpty )     | No      | array | No         | -          | -                     |
|                                  |         |       |            |            |                       |

## <a name="address"></a>1. ![badge](https://img.shields.io/badge/Optional-yellow) Property `root > address`

| Type                      | `array`                                                                                                             |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
|                           |                                                                                                                     |

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | True               |
| **Tuple validation** | See below          |
|                      |                    |

| Each item of this array must be | Description |
| ------------------------------- | ----------- |
| [items](#address_items)         | -           |
|                                 |             |

### <a name="autogenerated_heading_2"></a>1.1. root > address > items

| Type                      | `object`                                                                                                            |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
|                           |                                                                                                                     |

**Example:** 

```json
[
    1600,
    "Pennsylvania",
    "Avenue",
    "NW",
    "Washington"
]
```

## <a name="addressLines"></a>2. ![badge](https://img.shields.io/badge/Optional-yellow) Property `root > addressLines`

| Type                      | `array`                                                                                                             |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
|                           |                                                                                                                     |

**Description:** list of address lines

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |
|                      |                    |

| Each item of this array must be | Description |
| ------------------------------- | ----------- |
| [items](#addressLines_items)    | -           |
|                                 |             |

### <a name="autogenerated_heading_3"></a>2.1. root > addressLines > items

| Type                      | `object`                                                                                                            |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
|                           |                                                                                                                     |

## <a name="arrayEmpty"></a>3. ![badge](https://img.shields.io/badge/Optional-yellow) Property `root > arrayEmpty`

| Type                      | `array`                                                                                                             |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
|                           |                                                                                                                     |

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |
|                      |                    |

| Each item of this array must be | Description |
| ------------------------------- | ----------- |
| [items](#arrayEmpty_items)      | -           |
|                                 |             |

### <a name="autogenerated_heading_4"></a>3.1. root > arrayEmpty > items

| Type                      | `object`                                                                                                            |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
|                           |                                                                                                                     |

----------------------------------------------------------------------------------------------------------------------------
Generated using [json-schema-for-humans](https://github.com/coveooss/json-schema-for-humans) on date